tree
==============================

The SDSS SAS Tree structure.  See the documentation at http://sdss-tree.readthedocs.io/en/latest/

| |Build Status|
| |Coverage Status|

------------

This product contains the definition(s) of the SAS tree(s).
On installation it installs multiple tree definitions in a
manner that can be easily sourced or setup by users.

See https://trac.sdss.org/wiki/DataArchive/TreeProduct


.. |Build Status| image:: https://travis-ci.org/sdss/tree.svg?branch=master
   :target: https://travis-ci.org/sdss/tree

.. |Coverage Status| image:: https://coveralls.io/repos/github/sdss/tree/badge.svg?branch=master
   :target: https://coveralls.io/github/sdss/tree?branch=master
